/* ser_error.h
 * 
 * Defines the error codes for the library.
 * 
 * Copyright (C) 2000, Winford Engineering.
 * See file LICENSE.txt for details.
 * 	
 * Winford Engineering
 * www.winfordeng.com
 */
#ifndef ser_error_h
#define ser_error_h

/* General Note:
 * I have started by making invalid parameter passing errors
 * in the area of -101 and down.
 * I started invalid state (mode) errors at -150
 */
 
#define SER_SUCCESS                 0
#define SER_GENERAL_ERROR           -1
#define SER_SERIAL_ERROR            -10  // unable to open, read, or write to the serial port
#define SER_THREAD_ERROR            -11  // General error ocurred in the threads library used by this API.
#define SER_NOT_SUPPORTED			-12  // returned if an API function is not supported by a device
#define SER_PIPE_ERROR				-13  // Error creating a pipe
#define SER_READTHREAD_ERROR        -14  // Internal API error creating the reading thread or inside the reading thread
#define SER_EVENTTHREAD_ERROR       -15  // Internal API error creating the event thread of inside the event thread
#define SER_MALLOC_ERROR            -16  // Problem involving allocating memory
#define SER_WINDOWS_ERROR           -17  // Error specific to windows, such as creating a window, or window class

#define SER_INVALID_HANDLE          -101 //No device is currently open with that handle
#define SER_INVALID_MODEL           -102 //Model was invalid (doesnt exist)
#define SER_INVALID_BAUD            -103 //Invalid baudrate specified
#define SER_INVALID_PORT            -104 //Port specified is invalid for the device model
#define SER_INVALID_PORTMODE        -105 //There is no such mode for that port, or that mode is currently unavailable
#define SER_INVALID_PORTVALUE       -106 //Value passed to output function is out of valid range
#define SER_INVALID_EVENTID			-107 //Cannot assign that id value to an event
#define SER_INVALID_EVENTTYPE		-108 //Not one of the supported event types
#define SER_INVALID_BIT				-109 //Value passed identifying bit is out of range
#define SER_INVALID_PROPERTY        -110 //Not a valid property for the port specified
#define SER_INVALID_CHANNEL         -111 //Invalid analog channel number specified

#define SER_SERIALPORT_CONFLICT     -114 //Serial port specified is already in use
#define SER_DEVICE_NOTFOUND         -115 //Device is not present on the specified serial port, or is not powered up
#define SER_WRONG_PORTMODE          -150 //Device is not in the correct mode.
#define SER_EVENT_CONFLICT			-151 //This error likely occurs if a bit event is registered on a port whose port event is enabled

#define SER_TIMEOUT                 -201 //Timeout ocurred. Most likely communication has been lost w/ device	

#endif //ser_error_h