Attribute VB_Name = "ser_sr24_mod"
Option Explicit

'   ser_sr24_mod.bas
'   This file is the serial board module for use in Visual Basic
'   It contains function declarations and constant definitions,
'   variable type definitions, and the callback function which
'   makes hardware events possible
'
'   Revised:  November 2000
'   By:  BMB
'
'   Winford Engineering
'   www.winfordeng.com

'************************************************
' Data Structures
'************************************************
Public Type ser_event_spec
    type As Long
    eventfn As Long
    window As Long
    msgid As Long
    extra As Long
End Type

'************************************************
' Windows API function declarations
'************************************************
Public Declare Function mod_ser_lstrcpy Lib "kernel32" Alias "lstrcpyA" (ByVal lpString1 As String, ByVal lpString2 As Long) As Long
Public Declare Function mod_ser_lstrlen Lib "kernel32" Alias "lstrlenA" (ByVal lpString As Long) As Long

'************************************************
' Serial API function Declarations
'************************************************
Public Declare Function ser_sr24_open Lib "ser_sr24.dll" (ByVal serial As String, ByVal baud As Long, ByRef result As Long) As Long
Public Declare Function ser_sr24_verify_connection Lib "ser_sr24.dll" (ByVal handle As Long) As Long
Public Declare Function ser_sr24_reset_board Lib "ser_sr24.dll" (ByVal handle As Long) As Long
Public Declare Function ser_sr24_output_byte Lib "ser_sr24.dll" (ByVal handle As Long, ByVal port As Long, ByVal value As Long) As Long
Public Declare Function ser_sr24_input_byte Lib "ser_sr24.dll" (ByVal handle As Long, ByVal port As Long, ByRef value As Long) As Long
Public Declare Function ser_sr24_output_bit Lib "ser_sr24.dll" (ByVal handle As Long, ByVal port As Long, ByVal bit As Long, ByVal value As Long) As Long
Public Declare Function ser_sr24_input_bit Lib "ser_sr24.dll" (ByVal handle As Long, ByVal port As Long, ByVal bit As Long, ByRef value As Long) As Long
Public Declare Function ser_sr24_input_analog Lib "ser_sr24.dll" (ByVal handle As Long, ByVal channel As Long, ByRef value As Long) As Long
Public Declare Function ser_sr24_get_portmode Lib "ser_sr24.dll" (ByVal handle As Long, ByVal port As Long, ByVal property As Long) As Long
Public Declare Function ser_sr24_set_portmode Lib "ser_sr24.dll" (ByVal handle As Long, ByVal port As Long, ByVal property As Long, ByVal mode As Long) As Long
Public Declare Function ser_sr24_set_timeout Lib "ser_sr24.dll" (ByVal handle As Long, ByVal Timeout As Long) As Long
Public Declare Function ser_sr24_register_event Lib "ser_sr24.dll" (ByVal handle As Long, ByVal port As Long, ByVal bit As Long, ByVal id As Long) As Long
Public Declare Function ser_sr24_set_event_handler Lib "ser_sr24.dll" (ByVal handle As Long, ByRef event_ptr As ser_event_spec) As Long
Public Declare Function ser_returnvalue Lib "ser_sr24.dll" (ByVal value As ser_sr24) As Long
Public Declare Function ser_any2long Lib "ser_sr24.dll" Alias "ser_returnvalue" (ByVal value As Any) As Long

Public Declare Function ser_sr24_wait_event Lib "ser_sr24.dll" (ByVal handle As Long, ByRef events As Long, ByVal length As Long, ByVal Timeout As Long, ByRef value As Long) As Long

Public Declare Function ser_sr24_close Lib "ser_sr24.dll" (ByVal handle As Long) As Long
Public Declare Function ser_sr24_error_string Lib "ser_sr24.dll" (ByVal errorcode As Long) As Long


'************************************************
' Enumerated Variable Types
'************************************************
Public Enum BaudRate            'identifies the available baud rates
    SER_1200 = 9
    SER_2400 = 11
    SER_4800 = 12
    SER_9600 = 13
    SER_19200 = 14
    SER_38400 = 15
End Enum

Public Enum PortProperty        'identifies the port properties which may be configured
    SR24_BUFFER = 0                 'on for enabled, off for disabled
    SR24_DIRECTION = 1              'on for output, off for input
    SR24_TYPE = 2                   'on for analog, off for digital
End Enum

Public Enum PortMode            'identifies possible values for port properties
    SR24_BUFFER_ENABLED = 0
    SR24_BUFFER_DISABLED = 1
    SR24_DIRECTION_INPUT = 0
    SR24_DIRECTION_OUTPUT = 1
    SR24_TYPE_DIGITAL = 0
    SR24_TYPE_ANALOG = 1
End Enum


'************************************************
' Error codes
'************************************************
Public Const SER_SUCCESS = 0                   'No error
Public Const SER_GENERAL_ERROR = -1
Public Const SER_SERIAL_ERROR = -10            'unable to open, read, or write to the serial port
Public Const SER_THREAD_ERROR = -11            'general error ocurred in the threads library used by this API.
Public Const SER_NOT_SUPPORTED = -12           'returned if an API function is not supported by a device
Public Const SER_PIPE_ERROR = -13              'error creating a pipe
Public Const SER_READTHREAD_ERROR = -14        'internal API error creating the reading thread or inside the reading thread
Public Const SER_EVENTTHREAD_ERROR = -15       'internal API error creating the event thread of inside the event thread
Public Const SER_MALLOC_ERROR = -16            'problem involving allocating memory
Public Const SER_WINDOWS_ERROR = -17           'error specific to windows, such as creating a window, or window class

Public Const SER_INVALID_HANDLE = -101         'no device is currently open with that handle
Public Const SER_INVALID_MODEL = -102          'model was invalid (doesn't exist)
Public Const SER_INVALID_BAUD = -103           'invalid baudrate specified
Public Const SER_INVALID_PORT = -104           'port specified is invalid for the device model
Public Const SER_INVALID_PORTMODE = -105       'there is no such mode for that port, or that mode is currently unavailable
Public Const SER_INVALID_PORTVALUE = -106      'value passed to output function is out of valid range
Public Const SER_INVALID_EVENTID = -107        'cannot assign that id value to an event
Public Const SER_INVALID_EVENTTYPE = -108      'not one of the supported event types
Public Const SER_INVALID_BIT = -109            'value passed identifying bit is out of range
Public Const SER_INVALID_PROPERTY = -110       'not a valid property for the port specified
Public Const SER_INVALID_CHANNEL = -111        'invalid analog channel number specified

Public Const SER_SERIALPORT_CONFLICT = -114    'serial port specified is already in use
Public Const SER_DEVICE_NOTFOUND = -115        'device is not present on the specified serial port, or is not powered up
Public Const SER_WRONG_PORTMODE = -150         'device is not in the correct mode.
Public Const SER_EVENT_CONFLICT = -151         'this error likely occurs if a bit event is registered on a port whose port event is enabled

Public Const SER_TIMEOUT = -201                'timeout ocurred. Most likely communication has been lost w/ device


'************************************************
' Callback function for hardware events
'************************************************
Public Sub hw_callback(ByVal id As Long, ByVal value As Long, ByVal extra As ser_sr24)
    'This function is called by the API when a hardware event occurs.
    'This function calls an object method, which in turn raises an event
    'We can't raise the event directly since events can only be raised from class code
    '--------------------------------------------
    'Parameters: id - user-defined event id; tells us which event occurred
    '            value - value associated with the event (value of the port, etc)
    '            extra - extra value passed to callback; for VB, it will be the address of the ser_sr24 object
    '--------------------------------------------
    'Variable Declarations
    'Global
    'Local

    'Call 'trigger event' method for the passed object
    Call extra.TriggerEvent(id, value)
    
    
End Sub
